@@ -76,7 +76,6 @@ kbd_file_create (gchar *name, gint maxcols)
 		       "<GOK:keyboard name=\"", name, "\" wordcompletion=\"yes\">\n", NULL);
     g_io_channel_write_chars (kbd->io, buf, -1, &bytz, NULL);
     g_free (buf);
-    buf = g_strconcat ("\t<GOK:key ");
     g_io_channel_write_chars (kbd->io, "\t<GOK:key left = \"0\" right = \"1\" top = \"0\" bottom = \"1\" type=\"branchBack\">\n", -1, &bytz, NULL);
     g_io_channel_write_chars (kbd->io, "\t\t<GOK:label type = \"branchBack\">\345\220\216\351\200\200</GOK:label>\n", -1, &bytz, NULL);
     g_io_channel_write_chars (kbd->io, "\t</GOK:key>\n", -1, &bytz, NULL);
@@ -157,7 +156,8 @@ create_kbd_from_file (GIOChannel *infile, gchar *kbd_name, gint columns)
 	{
 	    if (error != NULL) 
 	    {
-		g_message (error->message);
+		g_message ("%s", error->message);
+		g_clear_error (&error);
 	    }
 	    continue;
 	}
@@ -208,6 +208,7 @@ int main (int argc, gchar **argv)
     else if (argc < 2 || !strcmp (argv[1], "--usage"))
     {
 	printf ("usage: create-branching-keyboard <infile.data> [<n_desired_rows>]\n");
+	return 1;
     }
     if (infile = g_io_channel_new_file (argv[1], "r", NULL))
     {
