@@ -1958,7 +1958,7 @@ GSList* gok_spy_append_node (GSList* nodes,
 					    firstcellname = NULL;
 					}
 					/* use row index */
-					pName = g_strdup_printf ("%d",irow);
+					pName = g_strdup_printf ("%d", (gint) irow);
 				    }
 				}
 				if (rowstring) SPI_freeString (rowstring);
@@ -1968,19 +1968,18 @@ GSList* gok_spy_append_node (GSList* nodes,
 					Accessible_unref (col);
 				}
 				if (colstring) {
-				    gchar* free_string = pName;
 				    if (strlen (colstring)) {
+					gchar *free_string = pName;
 					/* use header name */
 					pName = g_strconcat (pName, " ", colstring, NULL);
 					g_free (free_string);
 				    }
-				    else
-					SPI_freeString (colstring);
+				    SPI_freeString (colstring);
 				}
 				else {
 				    gchar *free_string = pName;
 				    /* use col index */
-				    pName = g_strconcat (pName, " ", g_strdup_printf ("%d",icol), NULL);
+				    pName = g_strdup_printf ("%s %d", pName, (gint) icol);
 				    g_free (free_string);
 				}
 				AccessibleTable_unref (table);
